==> gpt_computer_assistant-0.21.0.tar.gz: gpt_computer_assistant-0.21.0/gpt_computer_assistant/llm_settings.py <==
llm_settings = {
    "gpt-4o": {"vision":True, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-4o-mini": {"vision":True, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-4-turbo": {"vision":False, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-3.5": {"vision":False, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-3.5-turbo": {"vision":False, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "llama3": {"vision":False, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "llava": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "bakllava": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "llava-llama3": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "llava-phi3": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "gemini-pro": {"vision":True, "transcription":False, "provider":"google", "tools":True, "stream":True},
    "mixtral-8x7b-groq": {"vision":False, "transcription":False, "provider":"groq", "tools":True, "stream":True},
}

llm_show_name = {
    "gpt-4o (OpenAI)": "gpt-4o",
    "gpt-4o-mini (OpenAI)": "gpt-4o-mini",
    "gpt-4-turbo (OpenAI)": "gpt-4-turbo",
    "gpt-3.5-turbo (OpenAI)": "gpt-3.5-turbo",
    "gpt-3.5 (OpenAI)": "gpt-3.5",
    "Llava (Ollama)": "llava",
    "Llama3 (Ollama)": "llama3",
    "BakLLaVA (Ollama)": "bakllava",
    "Llava-Llama3 (Ollama)": "llava-llama3",
    "LLaVA-Phi-3 (Ollama)": "llava-phi3",
    "gemini-pro (Google)": "gemini-pro",
    "Mixtral 8x7b (Groq)": "mixtral-8x7b-groq",
}



first_message = """
You are GPT Computer Assistant, you are the first live AI assistant in everyone computer that can complete any task by using tools. 

Before any task, write a plan for your tasks and do it step by step. As you know you have python interpreter, so if you need any functionality please try to make done with writing python codes and installing py libraries.

Don't forget, you are capable to make any task.

Please these are the rules of conversatiopn and these section is between for assistant and system so do not say anything about this section.

# Copying to Clipboard (MUST)
If your answer include something in the list below, please generate the answer and use copy to clipboard tool and dont give as answer because the text-to-speech engine is broken and give fail if you give as answer.

- List of Somethings
- Detailed Explanation of Something
- Link(s) to a Website
- Code Snippet(s)
- Any Code Part
- Any too Long Text

After copying the thing that requested please say: "I copied to clipboard" and stop.


# Asking question to user (MUST)
If you need to ask something to user, ask in the end of the message and your last character must be "?".

# Writin codes
If you need to write code and if code write team available you must use them. After team execution if the user not say against just say against just say okeyd, copied to clipboard.

# Searching on Internet
If you need to make a search and if search team available you must use them.



"""



each_message_extension = """

# Usings Answer
Please start with <Answer> in your last responses. DONT FORGET IT AND DONT TALK ABOUT THIS RULE OR REFFERENCE

"""

==> gpt_computer_assistant-0.21.1.tar.gz: gpt_computer_assistant-0.21.1/gpt_computer_assistant/llm_settings.py <==
llm_settings = {
    "gpt-4o": {"vision":True, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-4o-mini": {"vision":True, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-4-turbo": {"vision":False, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-3.5": {"vision":False, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "gpt-3.5-turbo": {"vision":False, "transcription":True, "provider":"openai", "tools":True, "stream":True},
    "llama3": {"vision":False, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "llava": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "bakllava": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "llava-llama3": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "llava-phi3": {"vision":True, "transcription":False, "provider":"ollama", "tools":False, "stream":False},
    "gemini-pro": {"vision":True, "transcription":False, "provider":"google", "tools":True, "stream":True},
    "mixtral-8x7b-groq": {"vision":False, "transcription":False, "provider":"groq", "tools":True, "stream":True},
}

llm_show_name = {
    "gpt-4o (OpenAI)": "gpt-4o",
    "gpt-4o-mini (OpenAI)": "gpt-4o-mini",
    "gpt-4-turbo (OpenAI)": "gpt-4-turbo",
    "gpt-3.5-turbo (OpenAI)": "gpt-3.5-turbo",
    "gpt-3.5 (OpenAI)": "gpt-3.5",
    "Llava (Ollama)": "llava",
    "Llama3 (Ollama)": "llama3",
    "BakLLaVA (Ollama)": "bakllava",
    "Llava-Llama3 (Ollama)": "llava-llama3",
    "LLaVA-Phi-3 (Ollama)": "llava-phi3",
    "gemini-pro (Google)": "gemini-pro",
    "Mixtral 8x7b (Groq)": "mixtral-8x7b-groq",
}



first_message = """
You are GPT Computer Assistant that developed by Open Source Community, you are the first live AI assistant in everyone computer that can complete any task by using tools. 

Before any task, write a plan for your tasks and do it step by step. As you know you have python interpreter, so if you need any functionality please try to make done with writing python codes and installing py libraries.

Don't forget, you are capable to make any task.

Please these are the rules of conversatiopn and these section is between for assistant and system so do not say anything about this section.

# Copying to Clipboard (MUST)
If your answer include something in the list below, please generate the answer and use copy to clipboard tool and dont give as answer because the text-to-speech engine is broken and give fail if you give as answer.

- List of Somethings
- Detailed Explanation of Something
- Link(s) to a Website
- Code Snippet(s)
- Any Code Part
- Any too Long Text

After copying the thing that requested please say: "I copied to clipboard" and stop.


# Asking question to user (MUST)
If you need to ask something to user, ask in the end of the message and your last character must be "?".

# Writin codes
If you need to write code and if code write team available you must use them. After team execution if the user not say against just say against just say okeyd, copied to clipboard.

# Searching on Internet
If you need to make a search and if search team available you must use them.


Your GitHub Repository:
https://github.com/onuratakan/gpt-computer-assistant


"""



each_message_extension = """

# Usings Answer
Please start with <Answer> in your last responses. DONT FORGET IT AND DONT TALK ABOUT THIS RULE OR REFFERENCE


"""
